@@ -10,24 +10,32 @@
 # OR CONDITIONS OF ANY KIND, express or implied. See the License for the specific language governing permissions
 # and limitations under the License.
 #
+import base64
+from enum import Enum
 import os
 import nltk
 import boto3
-
+import tempfile
 from aws_lambda_powertools import Logger, Tracer
 
+s3 = boto3.client('s3')
+
+
 logger = Logger(service="SUMMARY_GENERATION")
 tracer = Tracer(service="SUMMARY_GENERATION")
 
-def set_nltk_data():
-    root = os.path.dirname(os.path.abspath(__file__))
-    download_dir = os.path.join(root, "nltk_data")
-    nltk.data.path.append(download_dir)
-
-
-def set_transformer_cache_dir(pathdir):
-    os.environ["TRANSFORMERS_CACHE"] = pathdir
+class Modality(Enum):
+    TEXT = (
+        'Text'
+    )
+    IMAGE = (
+        'Image'
+        
+    )
+    def __init__(self, status):
+        self.status = status
 
+    
 
 # read text file √from s3 bucket
 def read_file_from_s3(bucket, key):
@@ -41,3 +49,17 @@ def read_file_from_s3(bucket, key):
             f"Reason: {e}"
         )
         return None
+
+def download_file(bucket,key )-> str:
+        try: 
+            file_path = os.path.join(tempfile.gettempdir(), os.path.basename(key))
+            s3.download_file(bucket, key,file_path)
+            return file_path
+        except Exception as exp:
+            logger.error(f"Couldn\'t download file {key}/{file_path} from {bucket}: {exp}")
+
+
+def encode_image_to_base64(image_file_path,image_file) -> str:
+        with open(image_file_path, "rb") as image_file:
+            b64_image = base64.b64encode(image_file.read()).decode('utf8')       
+        return b64_image
\ No newline at end of file
