@@ -1,3 +1,6 @@
+from pkgutil import extend_path
+__path__ = extend_path(__path__, __name__)
+
 import abc
 import builtins
 import datetime
@@ -16,9 +19,9 @@ import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@cdklabs/generative-ai-cdk-constructs",
-    "0.1.94",
+    "0.1.198",
     __name__[0:-6],
-    "generative-ai-cdk-constructs@0.1.94.jsii.tgz",
+    "generative-ai-cdk-constructs@0.1.198.jsii.tgz",
 )
 
 __all__ = [
